@@ -29,7 +29,7 @@ LATEST="latest"
 function load_jenkins_vars() {
   if [ -e "jenkins-env" ]; then
     cat jenkins-env \
-      | grep -E "(JENKINS_URL|GIT_BRANCH|GIT_COMMIT|BUILD_NUMBER|ghprbSourceBranch|ghprbActualCommit|BUILD_URL|ghprbPullId|GH_TOKEN|CICO_API_KEY|API_TOKEN|JOB_NAME|RELEASE_VERSION|GITHUB_TOKEN)=" \
+      | grep -E "(JENKINS_URL|GIT_BRANCH|GIT_COMMIT|BUILD_NUMBER|ghprbSourceBranch|ghprbActualCommit|BUILD_URL|ghprbPullId|GH_TOKEN|CICO_API_KEY|API_TOKEN|JOB_NAME|RELEASE_VERSION|GITHUB_TOKEN|REPO|BRANCH)=" \
       | sed 's/^/export /g' \
       > ~/.jenkins-env
     source ~/.jenkins-env
@@ -121,28 +121,34 @@ function setup_repo() {
   cp -r /home/minishift_ci/payload $GOPATH/src/github.com/minishift/minishift
 }
 
-function setup_glide() {
-  # Setup Glide ("curl https://glide.sh/get | sh" not working due to https://github.com/Masterminds/glide/issues/708)
-  GLIDE_OS_ARCH=`go env GOHOSTOS`-`go env GOHOSTARCH`
-  GLIDE_TAG=v0.12.3
-  GLIDE_LATEST_RELEASE_URL="https://github.com/Masterminds/glide/releases/download/${GLIDE_TAG}/glide-${GLIDE_TAG}-${GLIDE_OS_ARCH}.tar.gz"
-  curl -LO ${GLIDE_LATEST_RELEASE_URL}
-  mkdir /tmp/glide
-  tar --directory=/tmp/glide -xvf glide-${GLIDE_TAG}-${GLIDE_OS_ARCH}.tar.gz
-  export PATH=$PATH:/tmp/glide/${GLIDE_OS_ARCH}
+function setup_godep() {
+  GODEP_OS_ARCH=`go env GOHOSTOS`-`go env GOHOSTARCH`
+  GODEP_TAG=v0.3.2
+  GODEP_LATEST_RELEASE_URL="https://github.com/golang/dep/releases/download/${GODEP_TAG}/dep-${GODEP_OS_ARCH}"
+  mkdir /tmp/godep
+  curl -L ${GODEP_LATEST_RELEASE_URL} -o /tmp/godep/dep
+  chmod +x /tmp/godep/dep
+  export PATH=$PATH:/tmp/godep/
 }
 
 function prepare_repo() {
   setup_golang;
   setup_repo;
-  setup_glide;
+  setup_godep;
   echo "CICO: Preparation complete"
 }
 
 function install_docs_prerequisite_packages() {
   # https://devops.profitbricks.com/tutorials/install-ruby-214-with-rvm-on-centos/
   # Prerequisite packages
-  sudo yum install -y libyaml-devel readline-devel zlib-devel libffi-devel openssl-devel sqlite-devel
+  sudo yum install -y libyaml-devel \
+                     readline-devel \
+                     zlib-devel \
+                     libffi-devel \
+                     openssl-devel \
+                     sqlite-devel \
+                     java-1.7.0-openjdk-devel
+
   # Install RVM
   gpg2 --keyserver hkp://keys.gnupg.net --recv-keys D39DC0E3
   curl -L get.rvm.io | bash -s stable
@@ -156,6 +162,12 @@ function install_docs_prerequisite_packages() {
   echo "CICO: Ascii Binder Installed"
 }
 
+########################################################
+# Exit with message on failure of last executed command
+# Arguments:
+#   $1 - Exit code of last executed command
+#   $2 - Error message
+########################################################
 function exit_on_failure() {
   if [[ "$1" != 0 ]]; then
     echo "$2"
@@ -176,7 +188,7 @@ function build_openshift_origin_docs() {
   cd ..
 }
 
-function artifacts_upload_on_pr_and_master_trigger() {
+function perform_artifacts_upload() {
   set +x
   # For PR build, GIT_BRANCH is set to branch name other than origin/master
   if [[ "$GIT_BRANCH" = "origin/master" ]]; then
@@ -208,13 +220,6 @@ function docs_tar_upload() {
 }
 
 function create_release_commit() {
-  # Set Terminal
-  export TERM=xterm-256color
-  # Add git a/c identity
-  git config user.email "29732253+minishift-bot@users.noreply.github.com"
-  git config user.name "Minishift Bot"
-  # Export GITHUB_ACCESS_TOKEN
-  export GITHUB_ACCESS_TOKEN=$GITHUB_TOKEN
   # Create master branch as git clone in CI doesn't create it
   git checkout -b master
   # Bump version and commit
@@ -256,10 +261,39 @@ function setup_build_environment() {
   runuser -l minishift_ci -c "/bin/bash centos_ci.sh"
 }
 
-function perform_release() {
-  setup_kvm_docker_machine_driver; # Required for integeration tests
-  cd gopath/src/github.com/minishift/minishift
+#######################################################################
+# Publish Minishift documentation after integrating it with
+# OpenShift documentation
+# Arguments:
+#   $1 - Repo Owner
+#   $2 - Branch name
+#   $3 - Location on the artifact server where documentation is hosted
+######################################################################
+function perform_docs_publish() {
+  REPO="https://github.com/$1/minishift"
 
+  git remote add remote-repo $REPO
+  git fetch remote-repo
+  git checkout -b docs-branch --track remote-repo/$2
+  git log -n 1 # Display last commit in log as reference
+
+  install_docs_prerequisite_packages;
+  make gen_adoc_tar
+  build_openshift_origin_docs $(pwd)/docs/build/minishift-adoc.tar;
+
+  mkdir -p $3
+  cp -r openshift-docs/_preview/openshift-origin $3/ # Copy the openshift-origin
+  # http://stackoverflow.com/a/22908437/1120530; Using --relative as --rsync-path not working
+  RSYNC_PASSWORD=$RSYNC_PASSWORD rsync -av --delete --relative $3/ minishift@artifacts.ci.centos.org::minishift/
+  echo "Minishift documentation is hosted at http://artifacts.ci.centos.org/minishift/$3/openshift-origin/latest/minishift/index.html"
+}
+
+function prepare_for_proxy() {
+  export INTEGRATION_PROXY_CUSTOM_PORT=8181 # needs to be an unused port
+  firewall-cmd --zone=public --add-port=$INTEGRATION_PROXY_CUSTOM_PORT/tcp;
+}
+
+function perform_release() {
   # Test everything before bumping the version
   make prerelease
   exit_on_failure "$?" "Pre-release tests failed."
@@ -267,7 +301,7 @@ function perform_release() {
   MINISHIFT_VM_DRIVER=kvm make integration_all
   exit_on_failure "$?" "Integration tests failed."
 
-  make link_check_docs IMAGE_UID=$(id -u) # Test docs builds and all links are valid
+  make link_check_docs # Test docs builds and all links are valid
   exit_on_failure "$?" "Documentation build failed."
 
   create_release_commit
@@ -280,7 +314,7 @@ function perform_release() {
   add_release_notes;
   exit_on_failure "$?" "Failed to update release notes of Minishift v$RELEASE_VERSION. Try to manually update the release notes here - https://github.com/${REPO_OWNER}/minishift/releases/tag/v$RELEASE_VERSION."
 
-  make gen_adoc_tar IMAGE_UID=$(id -u)
+  make gen_adoc_tar
   exit_on_failure "$?" "Documentation tarball build failed."
 
   docs_tar_upload $1
@@ -293,22 +327,22 @@ function perform_release() {
   curl http://minibot.19cf262c.svc.dockerapp.io:9009/hubot/centosci -H "Content-Type: application/json" -d '{"payload":{"status":"success","message":'"\"$MESSAGE\""',"url":'"\"$URL\""'}}' || true
 }
 
-function build_and_test() {
-  setup_kvm_docker_machine_driver;
-  cd $GOPATH/src/github.com/minishift/minishift
-  # Pull minishift/docs image to avoid building it
-  docker pull minishift/docs
+function perform_pr() {
   make prerelease synopsis_docs link_check_docs
-  # Run integration test with 'kvm' driver
-  MINISHIFT_VM_DRIVER=kvm make integration_all
-  echo "CICO: Tests ran successfully"
-
-  artifacts_upload_on_pr_and_master_trigger $1;
+  MINISHIFT_VM_DRIVER=kvm make integration_pr
+  perform_artifacts_upload $1;
 }
 
-function prepare_for_proxy() {
-  export INTEGRATION_PROXY_CUSTOM_PORT=8181 #needs to be an unused port
-  firewall-cmd --zone=public --add-port=$INTEGRATION_PROXY_CUSTOM_PORT/tcp;
+function perform_master() {
+  make prerelease synopsis_docs link_check_docs
+  MINISHIFT_VM_DRIVER=kvm make integration_all
+  perform_docs_publish "minishift" "master" "minishift/docs/master";
+  perform_artifacts_upload $1;
+}
+
+function perform_nightly() {
+  make prerelease synopsis_docs link_check_docs
+  MINISHIFT_ISO_URL=$1 MINISHIFT_VM_DRIVER=kvm make integration_all
 }
 
 if [[ "$UID" = 0 ]]; then
@@ -317,15 +351,34 @@ else
   source ~/jenkins-env # Source environment variables for minishift_ci user
   RSYNC_PASSWORD=$(echo $CICO_API_KEY | cut -d'-' -f1-2)
 
+  # Set Terminal
+  export TERM=xterm-256color
+  # Add git a/c identity
+  git config --global user.email "29732253+minishift-bot@users.noreply.github.com"
+  git config --global user.name "Minishift Bot"
+  # Export GITHUB_ACCESS_TOKEN
+  export GITHUB_ACCESS_TOKEN=$GITHUB_TOKEN
+
   prepare_repo;
+  setup_kvm_docker_machine_driver;
+  # Navigate to the repo
+  cd $GOPATH/src/github.com/minishift/minishift
 
   if [[ "$JOB_NAME" = "minishift-docs" ]]; then
-    cd gopath/src/github.com/minishift/minishift
-    make gen_adoc_tar IMAGE_UID=$(id -u)
-    docs_tar_upload $RSYNC_PASSWORD;
+    # REPO and BRANCH variables are populated via https://ci.centos.org/job/minishift-docs
+    REPO_OWNER=$(echo $REPO | cut -d"/" -f4)
+    perform_docs_publish "$REPO_OWNER" "$BRANCH" "minishift/docs/ondemand/$REPO_OWNER-$BRANCH";
   elif [[ "$JOB_NAME" = "minishift-release" ]]; then
     perform_release $RSYNC_PASSWORD;
-  else
-    build_and_test $RSYNC_PASSWORD;
+  elif [[ "$JOB_NAME" = "minishift-nightly-b2d" ]]; then
+    perform_nightly "b2d";
+  elif [[ "$JOB_NAME" = "minishift-nightly-minikube" ]]; then
+    perform_nightly "minikube";
+  elif [[ "$JOB_NAME" = "minishift-nightly-centos" ]]; then
+    perform_nightly "centos";
+  elif [[ "$JOB_NAME" = "minishift" ]]; then # Master job
+    perform_master $RSYNC_PASSWORD;
+  else # PR job
+    perform_pr $RSYNC_PASSWORD;
   fi
 fi
