@@ -23,6 +23,7 @@ import (
 	"github.com/docker/machine/libmachine"
 	registrationUtil "github.com/minishift/minishift/cmd/minishift/cmd/registration"
 	"github.com/minishift/minishift/cmd/minishift/cmd/util"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/pkg/minikube/cluster"
 	"github.com/minishift/minishift/pkg/minikube/constants"
 	minishiftConfig "github.com/minishift/minishift/pkg/minishift/config"
@@ -41,57 +42,71 @@ var (
 		Run:   runDelete,
 	}
 
-	forceMachineDeletion bool
-	clearCache           bool
+	forceFlag      bool
+	clearCacheFlag bool
 )
 
 func runDelete(cmd *cobra.Command, args []string) {
-	api := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+	if clearCacheFlag {
+		clearCache()
+	}
+
+	api := libmachine.NewClient(state.InstanceDirs.Home, state.InstanceDirs.Certs)
 	defer api.Close()
 
+	if !util.VMExists(api, constants.MachineName) {
+		atexit.Exit(0)
+	}
+
 	util.ExitIfUndefined(api, constants.MachineName)
 
-	if !forceMachineDeletion {
+	if !forceFlag {
 		hasConfirmed := pkgUtil.AskForConfirmation(fmt.Sprintf("You are deleting the Minishift VM: '%s'.", constants.MachineName))
 		if !hasConfirmed {
-			atexit.Exit(1)
-		}
-	}
-
-	if clearCache {
-		cachePath := constants.MakeMiniPath("cache")
-		err := os.RemoveAll(cachePath)
-		if err != nil {
-			atexit.ExitWithMessage(1, fmt.Sprintf("Error deleting Minishift cache: %v", err))
-		} else {
-			fmt.Printf("Removed the cache at: %s\n", cachePath)
+			atexit.Exit(0)
 		}
 	}
 
 	// Unregistration, do not allow to be skipped
-	registrationUtil.UnregisterHost(api, false, forceMachineDeletion)
+	registrationUtil.UnregisterHost(api, false, forceFlag)
 	fmt.Println("Deleting the Minishift VM...")
 	if err := cluster.DeleteHost(api); err != nil {
 		handleFailedHostDeletion(err)
 	}
 
-	removeInstanceConfigs()
+	removeInstanceAndKubeConfig()
 
 	fmt.Println("Minishift VM deleted.")
 }
 
+func clearCache() {
+	if !forceFlag {
+		hasConfirmed := pkgUtil.AskForConfirmation("This will delete the cache content for all profiles.")
+		if !hasConfirmed {
+			return
+		}
+	}
+	cachePath := state.InstanceDirs.Cache
+	err := os.RemoveAll(cachePath)
+	if err != nil {
+		atexit.ExitWithMessage(1, fmt.Sprintf("Error deleting Minishift cache: %v", err))
+	} else {
+		fmt.Printf("Removed cache content at: %s\n", cachePath)
+	}
+}
+
 func handleFailedHostDeletion(err error) {
-	if forceMachineDeletion {
-		err := os.RemoveAll(constants.MakeMiniPath("machines"))
+	if forceFlag {
+		err := os.RemoveAll(state.InstanceDirs.Machines)
 		if err != nil {
-			atexit.ExitWithMessage(1, fmt.Sprintf("Error deleting '%s': %v", constants.MakeMiniPath("machines"), err))
+			atexit.ExitWithMessage(1, fmt.Sprintf("Error deleting '%s': %v", state.InstanceDirs.Machines, err))
 		}
 	} else {
 		atexit.ExitWithMessage(1, fmt.Sprintf("Error deleting the Minishift VM: %v", err))
 	}
 }
 
-func removeInstanceConfigs() {
+func removeInstanceAndKubeConfig() {
 	exists := filehelper.Exists(minishiftConfig.InstanceConfig.FilePath)
 	if exists {
 		if err := minishiftConfig.InstanceConfig.Delete(); err != nil {
@@ -107,7 +122,7 @@ func removeInstanceConfigs() {
 }
 
 func init() {
-	deleteCmd.Flags().BoolVar(&forceMachineDeletion, "force", false, "Forces the deletion of the VM specific files in MINISHIFT_HOME.")
-	deleteCmd.Flags().BoolVar(&clearCache, "clear-cache", false, "Deletes all cached artifacts as part of the VM deletion.")
+	deleteCmd.Flags().BoolVarP(&forceFlag, "force", "f", false, "Forces the deletion of the VM specific files in MINISHIFT_HOME.")
+	deleteCmd.Flags().BoolVar(&clearCacheFlag, "clear-cache", false, "Deletes all cached content. This affects all profiles.")
 	RootCmd.AddCommand(deleteCmd)
 }
