@@ -23,6 +23,7 @@ import (
 
 	"github.com/docker/machine/libmachine"
 	"github.com/minishift/minishift/cmd/minishift/cmd/util"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/pkg/minikube/constants"
 	"github.com/minishift/minishift/pkg/minishift/openshift"
 	"github.com/minishift/minishift/pkg/util/os/atexit"
@@ -45,7 +46,7 @@ var serviceCmd = &cobra.Command{
 	Short: "Opens the URL for the specified service in the browser or prints it to the console.",
 	Long:  `Opens the URL for the specified service and namespace in the default browser or prints it to the console. If no namespace is provided, 'default' is assumed.`,
 	Run: func(cmd *cobra.Command, args []string) {
-		api := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+		api := libmachine.NewClient(state.InstanceDirs.Home, state.InstanceDirs.Certs)
 		defer api.Close()
 
 		util.ExitIfUndefined(api, constants.MachineName)
@@ -75,9 +76,11 @@ var serviceCmd = &cobra.Command{
 
 		if url {
 			stdOutURL(serviceSpecs, ip)
-		} else if inbrowser {
+		}
+		if inbrowser {
 			openInBrowser(serviceSpecs, ip)
-		} else {
+		}
+		if !url && !inbrowser {
 			printToStdOut(serviceSpecs, ip)
 		}
 	},
