@@ -46,12 +46,17 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 	"github.com/spf13/viper"
+
+	"github.com/minishift/minishift/cmd/minishift/state"
 )
 
 const (
 	showLibmachineLogs    = "show-libmachine-logs"
+	profileCmd            = "profile"
 	profileFlag           = "profile"
+	profileSetCmd         = "set"
 	enableExperimentalEnv = "MINISHIFT_ENABLE_EXPERIMENTAL"
+	invalidProfileName    = "Profile names must consist of alphanumeric characters only."
 )
 
 var viperWhiteList = []string{
@@ -71,23 +76,29 @@ var RootCmd = &cobra.Command{
 			isAddonInstallRequired bool
 		)
 
+		// If profile name is 'minishift' then ignore the vaild profile check.
+		if constants.ProfileName != constants.DefaultProfileName {
+			checkForValidProfileOrExit(cmd)
+		}
+
 		constants.MachineName = constants.ProfileName
+		constants.Minipath = constants.GetProfileHomeDir(constants.ProfileName)
 
 		// Initialize the instance directory structure
-		minishiftConfig.InstanceDirs = minishiftConfig.NewMinishiftDirs()
+		state.InstanceDirs = state.NewMinishiftDirs(constants.Minipath)
 
-		constants.KubeConfigPath = filepath.Join(constants.Minipath, "machines", constants.MachineName+"_kubeconfig")
+		constants.KubeConfigPath = filepath.Join(state.InstanceDirs.Machines, constants.MachineName+"_kubeconfig")
 
 		if cmd.Name() != "version" {
 			runAndValidateSetupCDK()
 		}
 
-		if !filehelper.Exists(minishiftConfig.InstanceDirs.Addons) {
+		if !filehelper.Exists(state.InstanceDirs.Addons) {
 			isAddonInstallRequired = true
 		}
 
 		// creating all directories for minishift run
-		createMinishiftDirs(minishiftConfig.InstanceDirs)
+		createMinishiftDirs(state.InstanceDirs)
 
 		// If AllInstanceConfig is not defined we should define it now.
 		if minishiftConfig.AllInstancesConfig == nil {
@@ -108,7 +119,7 @@ var RootCmd = &cobra.Command{
 		}
 
 		if isAddonInstallRequired {
-			if err := cmdUtil.UnpackAddons(minishiftConfig.InstanceDirs.Addons); err != nil {
+			if err := cmdUtil.UnpackAddons(state.InstanceDirs.Addons); err != nil {
 				atexit.ExitWithMessage(1, fmt.Sprintf("Error installing default add-ons : %s", err))
 			}
 		}
@@ -134,6 +145,11 @@ var RootCmd = &cobra.Command{
 		}
 
 		setDefaultActiveProfile()
+
+		// Adding minishift version information to debug logs
+		if glog.V(2) {
+			fmt.Println(fmt.Sprintf("-- minishift version: v%s+%s", version.GetMinishiftVersion(), version.GetCommitSha()))
+		}
 	},
 }
 
@@ -207,16 +223,48 @@ func initConfig() {
 	setupViper()
 }
 
+// initializeProfile always return profile name based on below checks.
+// 1. If profile set <PROFILE_NAME> is used then return PROFILE_NAME
+// 2. If --profile <PROFILE_NAME> then return PROFILE_NAME
+// 3. If no profile command or flag then return active profile name.
 func initializeProfile() string {
 	var (
-		profileName   string
-		err           error
-		activeProfile string
+		profileName     string
+		err             error
+		activeProfile   string
+		profileCmdAlias = []string{
+			"profiles",
+			"instance",
+		}
 	)
 
+	// Check if profileCmd is part of os.Args so that it takes preference instead `--profile` argument
+	var isProfileCmdUsed bool
+	for _, arg := range os.Args {
+		if arg == profileCmd || arg == profileCmdAlias[0] || arg == profileCmdAlias[1] {
+			isProfileCmdUsed = true
+		}
+	}
+
 	for i, arg := range os.Args {
-		if arg == "--"+profileFlag {
-			profileName = os.Args[i+1]
+		if !isProfileCmdUsed {
+			// This will match if `--profile` flag is used
+			if arg == "--"+profileFlag {
+				profileName = os.Args[i+1]
+				break
+			}
+		}
+		// This will match if we used profile or it's alias commands
+		if arg == profileCmd || arg == profileCmdAlias[0] || arg == profileCmdAlias[1] {
+			// This make sure if user specify profile command without any subcommand then
+			// it should not panic with out of index error
+			if len(os.Args) <= i+2 {
+				break
+			}
+			// For use cases when minishift profile set PROFILE_NAME is used
+			if os.Args[i+1] == profileSetCmd {
+				profileName = os.Args[i+2]
+			}
 			break
 		}
 	}
@@ -279,7 +327,7 @@ func performPostUpdateExecution(markerPath string) error {
 	if markerData.InstallAddon {
 		fmt.Println(fmt.Sprintf("Minishift was upgraded from v%s to v%s. Running post update actions.", markerData.PreviousVersion, version.GetMinishiftVersion()))
 		fmt.Print("--- Updating default add-ons ... ")
-		cmdUtil.UnpackAddons(minishiftConfig.InstanceDirs.Addons)
+		cmdUtil.UnpackAddons(state.InstanceDirs.Addons)
 		fmt.Println("OK")
 		fmt.Println(fmt.Sprintf("Default add-ons %s installed", strings.Join(cmdUtil.DefaultAssets, ", ")))
 	}
@@ -299,7 +347,7 @@ func ensureAllInstanceConfigPath(configPath string) {
 	}
 }
 
-func createMinishiftDirs(dirs *minishiftConfig.MinishiftDirs) {
+func createMinishiftDirs(dirs *state.MinishiftDirs) {
 	dirPaths := reflect.ValueOf(*dirs)
 
 	for i := 0; i < dirPaths.NumField(); i++ {
@@ -332,6 +380,23 @@ func setDefaultActiveProfile() {
 	}
 }
 
+// checkForValidProfileOrExit checks if a profile exist or not when --profile flag used.
+// If profile not exist then it will error out with message.
+func checkForValidProfileOrExit(cmd *cobra.Command) {
+	if !cmdUtil.IsValidProfileName(constants.ProfileName) {
+		atexit.ExitWithMessage(1, invalidProfileName)
+	}
+	if cmd.Parent() != nil {
+		// This condition true for each command execpt `minishift profile <subcommand>` and `minishift start ...``
+		if cmd.Parent().Name() != profileCmd && cmd.Name() != startCmd.Name() {
+			if !cmdUtil.IsValidProfile(constants.ProfileName) {
+				atexit.ExitWithMessage(1, fmt.Sprintf("Profile: %s doesn't exist, Use `minishift profile set %s` or `minishift start --profile %s` to create", constants.ProfileName, constants.ProfileName, constants.ProfileName))
+			}
+		}
+	}
+
+}
+
 func cdkMarkerFileExists(markerPath string) bool {
 	if _, err := os.Stat(markerPath); os.IsNotExist(err) {
 		return false
