@@ -28,9 +28,10 @@ import (
 	"io/ioutil"
 	"path/filepath"
 
+	"github.com/minishift/minishift/cmd/minishift/state"
+	"github.com/minishift/minishift/cmd/testing/cli"
 	"github.com/minishift/minishift/pkg/minikube/constants"
 	minishiftConfig "github.com/minishift/minishift/pkg/minishift/config"
-	"github.com/minishift/minishift/pkg/testing/cli"
 )
 
 var configTests = []cli.TestOption{
@@ -103,7 +104,7 @@ func TestPreRunDirectories(t *testing.T) {
 
 	cli.RunCommand(RootCmd.PersistentPreRun)
 
-	dirPaths := reflect.ValueOf(*minishiftConfig.InstanceDirs)
+	dirPaths := reflect.ValueOf(*state.InstanceDirs)
 	for i := 0; i < dirPaths.NumField(); i++ {
 		dir := dirPaths.Field(i).Interface().(string)
 		_, err := os.Stat(dir)
@@ -139,6 +140,31 @@ func TestViperAndFlags(t *testing.T) {
 	}
 }
 
+func TestInitializeProfile(t *testing.T) {
+	oldArgs := os.Args
+	defer func() { os.Args = oldArgs }()
+	Testdata := []struct {
+		Args   []string
+		Result string
+	}{
+		{[]string{"minishift", "profile", "set", "hello"}, "hello"},
+		{[]string{"minishift", "profiles", "set", "hello"}, "hello"},
+		{[]string{"minishift", "instance", "set", "hello"}, "hello"},
+		{[]string{"minishift", "start", "--profile", "hello"}, "hello"},
+		{[]string{"minishift", "ip", "--profile", "hello"}, "hello"},
+		{[]string{"minishift", "status", "--profile", "hello"}, "hello"},
+	}
+
+	for _, testInput := range Testdata {
+		os.Args = testInput.Args
+		got := initializeProfile()
+		if got != testInput.Result {
+			t.Errorf("Got %s, Expected %s as profile Name", got, testInput.Result)
+		}
+
+	}
+}
+
 func TestCDKMarkerFileExist(t *testing.T) {
 	// Make sure we create the required directories.
 	tempDir, err := ioutil.TempDir("", "minishift-test-start-cmd-")
