@@ -33,6 +33,7 @@ import (
 	"github.com/golang/glog"
 	"github.com/minishift/minishift/cmd/minishift/cmd/addon"
 	configCmd "github.com/minishift/minishift/cmd/minishift/cmd/config"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	addonbindata "github.com/minishift/minishift/out/bindata"
 	"github.com/minishift/minishift/pkg/minikube/cluster"
 	"github.com/minishift/minishift/pkg/minikube/constants"
@@ -82,7 +83,7 @@ var cdkSetupCmd = &cobra.Command{
 func init() {
 	cdkSetupCmd.Flags().StringVar(&homeDir, homeDirFlag, constants.Minipath, "Sets the Minishift home directory.")
 	cdkSetupCmd.Flags().StringVar(&defaultDriver, defaultDriverFlag, constants.DefaultVMDriver, "Sets the default VM driver.")
-	cdkSetupCmd.Flags().BoolVar(&forceInstall, forceInstallFlag, false, "Forces the deletion of the exsiting Minishift install, if it exists.")
+	cdkSetupCmd.Flags().BoolVar(&forceInstall, forceInstallFlag, false, "Forces the deletion of the existing Minishift install, if it exists.")
 	RootCmd.AddCommand(cdkSetupCmd)
 }
 
@@ -91,22 +92,40 @@ func runCdkSetup(cmd *cobra.Command, args []string) {
 	fmt.Println("CDK 3 setup complete.")
 }
 
-func SetupCDK() {
+func isDefaultProfile() bool {
+	return constants.ProfileName == constants.DefaultProfileName
+}
 
+func SetupCDK() {
 	// When profile name is not default we need to fix the homedir
-	if constants.ProfileName != constants.DefaultProfileName {
-		homeDir = constants.GetProfileHomeDir()
+	if !isDefaultProfile() {
+		cdkMarkerForDefaultProfile := filepath.Join(constants.GetMinishiftHomeDir(), CDKMarker)
+		if !cdkMarkerFileExists(cdkMarkerForDefaultProfile) {
+			SetupCDKMessage()
+		}
+		homeDir = constants.GetProfileHomeDir(constants.ProfileName)
 	}
 	constants.Minipath = homeDir
 	fmt.Println(fmt.Sprintf("Setting up CDK 3 on host using '%s' as Minishift's home directory", constants.Minipath))
 
 	ensureNoExistingConfigurationExists(os.Stdout, os.Stdin, homeDir)
 
-	isoCachePath, ocCachePath, configDir := createDirectories(homeDir)
-	unpackIso(isoCachePath)
-	unpackOc(ocCachePath)
-	createConfig(configDir, isoCachePath)
+	// Initialize the instance directory structure
+	state.InstanceDirs = state.NewMinishiftDirs(homeDir)
 
+	isoCachePath, ocCachePath, configDir := createDirectories(homeDir)
+
+	// Don't unpack ISO and OC for non-default profile
+	if isDefaultProfile() {
+		unpackIso(isoCachePath)
+		unpackOc(ocCachePath)
+	} else {
+		// Use global cached ISO for non-default profile
+		state.InstanceDirs.IsoCache = filepath.Join(constants.GetMinishiftHomeDir(), "cache", "iso")
+		isoCachePath = path.Join(state.InstanceDirs.IsoCache, isoName)
+	}
+
+	createConfig(configDir, isoCachePath)
 	createCDKMarker(homeDir)
 
 	addOnManager := addon.GetAddOnManager()
@@ -115,21 +134,32 @@ func SetupCDK() {
 }
 
 func createDirectories(baseDir string) (string, string, string) {
+	var (
+		isoCachePath string
+		ocCachePath  string
+	)
 	// need to rebuild the directories manually here, since OcCachePath is already initialised. Improving this requires some
 	// refactoring upstream (HF)
 	configDir := path.Join(baseDir, "config")
 	err := os.MkdirAll(configDir, 0777)
 	check(err)
 
-	isoCacheDir := path.Join(baseDir, "cache", "iso")
-	err = os.MkdirAll(isoCacheDir, 0777)
+	cacheDir := path.Join(baseDir, "cache")
+	err = os.MkdirAll(cacheDir, 0777)
 	check(err)
-	isoCachePath := path.Join(isoCacheDir, isoName)
 
-	ocCacheDir := path.Join(baseDir, "cache", "oc", version.GetOpenShiftVersion())
-	err = os.MkdirAll(ocCacheDir, 0777)
-	check(err)
-	ocCachePath := path.Join(ocCacheDir, constants.OC_BINARY_NAME)
+	// Only create ISO and OC cache directories for default profile
+	if isDefaultProfile() {
+		isoCacheDir := path.Join(cacheDir, "iso")
+		err = os.MkdirAll(isoCacheDir, 0777)
+		check(err)
+		isoCachePath = path.Join(isoCacheDir, isoName)
+
+		ocCacheDir := path.Join(cacheDir, "oc", version.GetOpenShiftVersion(), runtime.GOOS)
+		err = os.MkdirAll(ocCacheDir, 0777)
+		check(err)
+		ocCachePath = path.Join(ocCacheDir, constants.OC_BINARY_NAME)
+	}
 
 	addonsDir := path.Join(baseDir, "addons")
 	err = os.MkdirAll(addonsDir, 0777)
@@ -224,7 +254,7 @@ func ensureNoExistingConfigurationExists(w io.Writer, r io.Reader, baseDir strin
 }
 
 func machineExists(api *libmachine.Client) bool {
-	status, _ := cluster.GetHostStatus(api)
+	status, _ := cluster.GetHostStatus(api, constants.MachineName)
 
 	if status == "Does Not Exist" {
 		return false
@@ -295,8 +325,7 @@ func SetupCDKMessage() {
 func getVMDriverFromDefaultConfig() string {
 	// Check if config.json exists for default profile.
 	defaultConfigFile := filepath.Join(constants.GetMinishiftHomeDir(), "config", "config.json")
-	_, err := os.Stat(defaultConfigFile)
-	if os.IsNotExist(err) {
+	if _, err := os.Stat(defaultConfigFile); os.IsNotExist(err) {
 		SetupCDKMessage()
 	}
 
