@@ -18,10 +18,11 @@ package cmd
 
 import (
 	"fmt"
-	"os"
 	"runtime"
 	"strings"
 
+	"os"
+
 	"github.com/asaskevich/govalidator"
 	units "github.com/docker/go-units"
 	"github.com/docker/machine/libmachine"
@@ -33,6 +34,7 @@ import (
 	configCmd "github.com/minishift/minishift/cmd/minishift/cmd/config"
 	registrationUtil "github.com/minishift/minishift/cmd/minishift/cmd/registration"
 	cmdUtil "github.com/minishift/minishift/cmd/minishift/cmd/util"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/pkg/minikube/cluster"
 	"github.com/minishift/minishift/pkg/minikube/constants"
 	minishiftCluster "github.com/minishift/minishift/pkg/minishift/cluster"
@@ -44,9 +46,9 @@ import (
 	"github.com/minishift/minishift/pkg/minishift/hostfolder"
 	minishiftNetwork "github.com/minishift/minishift/pkg/minishift/network"
 	"github.com/minishift/minishift/pkg/minishift/openshift"
+	openshiftVersion "github.com/minishift/minishift/pkg/minishift/openshift/version"
 	profileActions "github.com/minishift/minishift/pkg/minishift/profile"
 	"github.com/minishift/minishift/pkg/minishift/provisioner"
-
 	"github.com/minishift/minishift/pkg/util"
 	"github.com/minishift/minishift/pkg/util/os/atexit"
 	"github.com/minishift/minishift/pkg/util/progressdots"
@@ -60,13 +62,14 @@ import (
 const (
 	commandName             = "start"
 	defaultInsecureRegistry = "172.30.0.0/16"
-	unsupportedIsoUrlFormat = "Unsupported value for iso-url. It can be an URL, file URI or one of the following short names: [b2d centos]."
 )
 
 var (
-	dockerEnv     []string
-	openShiftEnv  []string
-	shellProxyEnv string
+	dockerEnv               []string
+	openShiftEnv            []string
+	shellProxyEnv           string
+	unsupportedIsoUrlFormat = fmt.Sprintf("Unsupported value for iso-url. It can be a URL, file URI or one of the following aliases: [%s].",
+		strings.Join(minishiftConstants.ValidIsoAliases, ","))
 )
 
 var (
@@ -147,7 +150,9 @@ For the latter see 'minishift config -h'.`,
 
 // runStart handles all command line arguments, launches the VM and provisions OpenShift
 func runStart(cmd *cobra.Command, args []string) {
-	libMachineClient := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+	fmt.Println(fmt.Sprintf("-- Starting profile '%s'", constants.ProfileName))
+
+	libMachineClient := libmachine.NewClient(state.InstanceDirs.Home, state.InstanceDirs.Certs)
 	defer libMachineClient.Close()
 
 	ensureNotRunning(libMachineClient, constants.MachineName)
@@ -164,7 +169,8 @@ func runStart(cmd *cobra.Command, args []string) {
 
 	proxyConfig := handleProxies()
 
-	fmt.Printf("-- Starting local OpenShift cluster")
+	fmt.Print("-- Starting local OpenShift cluster")
+
 	hostVm := startHost(libMachineClient)
 	registrationUtil.RegisterHost(libMachineClient)
 
@@ -193,11 +199,10 @@ func runStart(cmd *cobra.Command, args []string) {
 
 	requestedOpenShiftVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
 	if !isRestart {
-		importContainerImages(hostVm, requestedOpenShiftVersion)
+		importContainerImages(hostVm.Driver, libMachineClient, requestedOpenShiftVersion)
 	}
 
-	// For downstream make sure we use cacheOc version as specified in Makefile
-	ocPath := cmdUtil.CacheOc(version.GetOpenShiftVersion())
+	ocPath := cmdUtil.CacheOc(clusterup.DetermineOcVersion(requestedOpenShiftVersion))
 	clusterUpConfig := &clusterup.ClusterUpConfig{
 		OpenShiftVersion: requestedOpenShiftVersion,
 		MachineName:      constants.MachineName,
@@ -228,7 +233,13 @@ func runStart(cmd *cobra.Command, args []string) {
 
 	if !isRestart {
 		postClusterUp(hostVm, clusterUpConfig)
-		exportContainerImages(hostVm, requestedOpenShiftVersion)
+		exportContainerImages(hostVm.Driver, libMachineClient, requestedOpenShiftVersion)
+	}
+	if isRestart {
+		err = cmdUtil.SetOcContext(minishiftConfig.AllInstancesConfig.ActiveProfile)
+		if err != nil {
+			fmt.Println(fmt.Sprintf("Could not set oc CLI context for: %s", profileActions.GetActiveProfile()))
+		}
 	}
 }
 
@@ -305,6 +316,7 @@ func startHost(libMachineClient *libmachine.Client) *host.Host {
 	// Configuration used for creation/setup of the Virtual Machine
 	machineConfig := &cluster.MachineConfig{
 		MinikubeISO:      determineIsoUrl(viper.GetString(configCmd.ISOUrl.Name)),
+		ISOCacheDir:      state.InstanceDirs.IsoCache,
 		Memory:           calculateMemorySize(viper.GetString(configCmd.Memory.Name)),
 		CPUs:             viper.GetInt(configCmd.CPUs.Name),
 		DiskSize:         calculateDiskSize(viper.GetString(configCmd.DiskSize.Name)),
@@ -336,12 +348,12 @@ func startHost(libMachineClient *libmachine.Client) *host.Host {
 			IPAddress: viper.GetString(configCmd.IPAddress.Name),
 			Netmask:   viper.GetString(configCmd.Netmask.Name),
 			Gateway:   viper.GetString(configCmd.Gateway.Name),
-			DNS1:      viper.GetString(configCmd.Nameserver.Name),
+			DNS1:      viper.GetString(configCmd.NameServer.Name),
 		}
 
 		// Configure networking on startup only works on Hyper-V
 		if networkSettings.IPAddress != "" {
-			minishiftNetwork.ConfigureNetworking(constants.MachineName, networkSettings)
+			minishiftNetwork.ConfigureNetworking(constants.MachineName, machineConfig.VMDriver, networkSettings)
 		}
 	}
 
@@ -383,21 +395,37 @@ func addActiveProfileInformation() {
 	}
 }
 
-func importContainerImages(hostVm *host.Host, openShiftVersion string) {
+func importContainerImages(driver drivers.Driver, api libmachine.API, openShiftVersion string) {
 	if !viper.GetBool(configCmd.ImageCaching.Name) {
 		return
 	}
 
-	handler := getImageHandler(hostVm)
+	images := viper.GetStringSlice(configCmd.CacheImages.Name)
+	for _, coreImage := range image.GetOpenShiftImageNames(openShiftVersion) {
+		if !stringUtils.Contains(images, coreImage) {
+			images = append(images, coreImage)
+		}
+	}
+
+	envMap, err := cluster.GetHostDockerEnv(api)
+	if err != nil {
+		atexit.ExitWithMessage(1, fmt.Sprintf("Error determining Docker settings for image import: %v", err))
+	}
+
+	handler := getImageHandler(driver, envMap)
 	config := &image.ImageCacheConfig{
-		HostCacheDir: constants.MakeMiniPath("cache", "images"),
-		CachedImages: image.GetOpenShiftImageNames(openShiftVersion),
+		HostCacheDir: state.InstanceDirs.ImageCache,
+		CachedImages: images,
+		Out:          os.Stdout,
+	}
+	_, err = handler.ImportImages(config)
+	if err != nil {
+		fmt.Println(fmt.Sprintf("  WARN: At least one image could not be imported. Error: %s ", err.Error()))
 	}
-	handler.ImportImages(config)
 }
 
-func getImageHandler(hostVm *host.Host) image.ImageHandler {
-	handler, err := image.NewDockerImageHandler(hostVm.Driver)
+func getImageHandler(driver drivers.Driver, envMap map[string]string) image.ImageHandler {
+	handler, err := image.NewOciImageHandler(driver, envMap)
 	if err != nil {
 		atexit.ExitWithMessage(1, fmt.Sprintf("Unable to create image handler: %v", err))
 	}
@@ -406,22 +434,34 @@ func getImageHandler(hostVm *host.Host) image.ImageHandler {
 }
 
 // exportContainerImages exports the OpenShift images in a background process (by calling 'minishift image export')
-func exportContainerImages(hostVm *host.Host, version string) {
+func exportContainerImages(driver drivers.Driver, api libmachine.API, version string) {
 	if !viper.GetBool(configCmd.ImageCaching.Name) {
 		return
 	}
 
-	handler := getImageHandler(hostVm)
+	images := viper.GetStringSlice(configCmd.CacheImages.Name)
+	for _, coreImage := range image.GetOpenShiftImageNames(version) {
+		if !stringUtils.Contains(images, coreImage) {
+			images = append(images, coreImage)
+		}
+	}
+
+	envMap, err := cluster.GetHostDockerEnv(api)
+	if err != nil {
+		atexit.ExitWithMessage(1, fmt.Sprintf("Error determining Docker settings for image import: %v", err))
+	}
+
+	handler := getImageHandler(driver, envMap)
 	config := &image.ImageCacheConfig{
-		HostCacheDir: constants.MakeMiniPath("cache", "images"),
-		CachedImages: image.GetOpenShiftImageNames(version),
+		HostCacheDir: state.InstanceDirs.ImageCache,
+		CachedImages: images,
 	}
 
 	if handler.AreImagesCached(config) {
 		return
 	}
 
-	exportCmd, err := image.CreateExportCommand(version)
+	exportCmd, err := image.CreateExportCommand(version, constants.ProfileName, images)
 	if err != nil {
 		atexit.ExitWithMessage(1, fmt.Sprintf("Error creating export command: %v", err))
 	}
@@ -503,7 +543,7 @@ func initStartFlags() *flag.FlagSet {
 		startFlagSet.String(configCmd.IPAddress.Name, "", "Specify IP address to assign to the instance (experimental - Hyper-V only)")
 		startFlagSet.String(configCmd.Netmask.Name, "24", "Specify netmask to use for the IP address. Ignored if no IP address specified (experimental - Hyper-V only)")
 		startFlagSet.String(configCmd.Gateway.Name, "", "Specify gateway to use for the instance. Ignored if no IP address specified (experimental - Hyper-V only)")
-		startFlagSet.String(configCmd.Nameserver.Name, "8.8.8.8", "Specify nameserver to use for the instance. Ignored if no IP address specified (experimental - Hyper-V only)")
+		startFlagSet.String(configCmd.NameServer.Name, "8.8.8.8", "Specify nameserver to use for the instance. Ignored if no IP address specified (experimental - Hyper-V only)")
 	}
 
 	if minishiftConfig.EnableExperimental {
@@ -607,7 +647,7 @@ func ensureNotRunning(client *libmachine.Client, machineName string) {
 func validateOpenshiftVersion() {
 	requestedVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
 
-	valid, err := clusterup.ValidateOpenshiftMinVersion(requestedVersion, constants.MinOpenshiftSupportedVersion)
+	valid, err := openshiftVersion.IsGreaterOrEqualToBaseVersion(requestedVersion, constants.MinimumSupportedOpenShiftVersion)
 	if err != nil {
 		atexit.ExitWithMessage(1, err.Error())
 	}
@@ -615,7 +655,7 @@ func validateOpenshiftVersion() {
 	if !valid {
 		fmt.Printf("Minishift does not support OpenShift version %s. "+
 			"You need to use a version >= %s\n", viper.GetString(configCmd.OpenshiftVersion.Name),
-			constants.MinOpenshiftSupportedVersion)
+			constants.MinimumSupportedOpenShiftVersion)
 		atexit.Exit(1)
 	}
 
@@ -633,6 +673,7 @@ func validateOpenshiftVersion() {
 func setSubscriptionManagerParameters() {
 	minishiftCluster.RegistrationParameters.Username = viper.GetString(configCmd.Username.Name)
 	minishiftCluster.RegistrationParameters.Password = viper.GetString(configCmd.Password.Name)
+	minishiftCluster.RegistrationParameters.IsTtySupported = util.IsTtySupported()
 	minishiftCluster.RegistrationParameters.GetUsernameInteractive = getUsernameInteractive
 	minishiftCluster.RegistrationParameters.GetPasswordInteractive = getPasswordInteractive
 }
