@@ -18,16 +18,18 @@ package util
 
 import (
 	"fmt"
+	"regexp"
 
 	"github.com/docker/machine/libmachine"
 	"github.com/docker/machine/libmachine/drivers"
 	"github.com/docker/machine/libmachine/state"
 	"github.com/minishift/minishift/pkg/minikube/cluster"
-	"github.com/minishift/minishift/pkg/minikube/constants"
 	profileActions "github.com/minishift/minishift/pkg/minishift/profile"
 	"github.com/minishift/minishift/pkg/util/os/atexit"
 
+	cmdState "github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/out/bindata"
+	"github.com/minishift/minishift/pkg/minikube/constants"
 )
 
 var (
@@ -66,16 +68,23 @@ func ExitIfNotRunning(driver drivers.Driver, machineName string) {
 
 func GetVMStatus(profileName string) string {
 	var status string
-	profileActions.UpdateProfileConstants(profileName)
-	api := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+	profileDirs := cmdState.NewMinishiftDirs(constants.GetProfileHomeDir(profileName))
+
+	api := libmachine.NewClient(profileDirs.Home, profileDirs.Certs)
 	defer api.Close()
-	status, err := cluster.GetHostStatus(api)
+	status, err := cluster.GetHostStatus(api, profileName)
 	if err != nil {
 		status = fmt.Sprintf("Error getting the VM status: %s", err.Error())
 	}
 	return status
 }
 
+func DoesVMExist(profileName string) bool {
+	api := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+	defer api.Close()
+	return VMExists(api, profileName)
+}
+
 // UnpackAddons will unpack the default addons into addons default dir
 func UnpackAddons(addonsDir string) error {
 	for _, asset := range DefaultAssets {
@@ -97,3 +106,9 @@ func IsValidProfile(profileName string) bool {
 	}
 	return false
 }
+
+// IsValidProfileName return true if profile name follow ^[a-zA-Z0-9]+[\w+-]*$
+func IsValidProfileName(profileName string) bool {
+	rr := regexp.MustCompile(`^[a-zA-Z0-9]+[\w+-]*$`)
+	return rr.MatchString(profileName)
+}
