@@ -19,7 +19,7 @@ package cmd
 import (
 	"testing"
 
-	"github.com/minishift/minishift/pkg/testing/cli"
+	"github.com/minishift/minishift/cmd/testing/cli"
 	"regexp"
 )
 
