@@ -132,10 +132,10 @@ func DeleteHost(api libmachine.API) error {
 	return m.ToError()
 }
 
-// GetHostStatus gets the status of the host VM.
-func GetHostStatus(api libmachine.API) (string, error) {
+// GetHostStatus gets the status of the host VM with the specified name.
+func GetHostStatus(api libmachine.API, machine string) (string, error) {
 	dne := "Does Not Exist"
-	exists, err := api.Exists(constants.MachineName)
+	exists, err := api.Exists(machine)
 	if err != nil {
 		return "", err
 	}
@@ -143,7 +143,7 @@ func GetHostStatus(api libmachine.API) (string, error) {
 		return dne, nil
 	}
 
-	host, err := api.Load(constants.MachineName)
+	host, err := api.Load(machine)
 	if err != nil {
 		return "", err
 	}
@@ -162,6 +162,7 @@ type sshAble interface {
 // MachineConfig contains the parameters used to start a cluster.
 type MachineConfig struct {
 	MinikubeISO      string
+	ISOCacheDir      string
 	Memory           int
 	CPUs             int
 	DiskSize         int
@@ -199,12 +200,6 @@ func createDriverOptions(driver drivers.Driver, explicitOptions map[string]inter
 // It also checks sha256sum if present and then put ISO to cached directory.
 func (m *MachineConfig) CacheMinikubeISOFromURL() error {
 	fmt.Println(fmt.Sprintf("\n   Downloading ISO '%s'", m.MinikubeISO))
-	tmpISOFile, err := os.Create(m.GetISOCacheFilepath() + ".part")
-	if err != nil {
-		return err
-	}
-	defer tmpISOFile.Close()
-
 	response, err := http.Get(m.MinikubeISO)
 	if err != nil {
 		return err
@@ -215,6 +210,16 @@ func (m *MachineConfig) CacheMinikubeISOFromURL() error {
 		return fmt.Errorf("Received %d response from %s while trying to download the ISO", response.StatusCode, m.MinikubeISO)
 	}
 
+	err = os.MkdirAll(filepath.Join(m.ISOCacheDir, minishiftUtil.GetIsoPath(m.MinikubeISO)), os.ModePerm)
+	if err != nil {
+		return err
+	}
+	tmpISOFile, err := os.Create(m.GetISOCacheFilepath() + ".part")
+	if err != nil {
+		return err
+	}
+	defer tmpISOFile.Close()
+
 	var iso io.Reader
 	iso = response.Body
 	hasher := sha256.New()
@@ -274,10 +279,10 @@ func renameFile(oldFile, newFile *os.File) error {
 func (m *MachineConfig) getChecksum(baseUrl string) string {
 	checksumURL := fmt.Sprintf(baseUrl + ".sha256")
 	checksumResp, err := http.Get(checksumURL)
-	defer checksumResp.Body.Close()
 	if err != nil {
 		return ""
 	}
+	defer checksumResp.Body.Close()
 
 	if checksumResp.StatusCode != 200 {
 		return ""
@@ -303,7 +308,7 @@ func (m *MachineConfig) ShouldCacheMinikubeISO() bool {
 }
 
 func (m *MachineConfig) GetISOCacheFilepath() string {
-	return filepath.Join(constants.Minipath, "cache", "iso", filepath.Base(m.MinikubeISO))
+	return filepath.Join(m.ISOCacheDir, minishiftUtil.GetIsoPath(m.MinikubeISO), filepath.Base(m.MinikubeISO))
 }
 
 func (m *MachineConfig) GetISOFileURI() string {
@@ -314,7 +319,7 @@ func (m *MachineConfig) GetISOFileURI() string {
 	if urlObj.Scheme == fileScheme {
 		return m.MinikubeISO
 	}
-	isoPath := filepath.Join(constants.Minipath, "cache", "iso", filepath.Base(m.MinikubeISO))
+	isoPath := m.GetISOCacheFilepath()
 	// As this is a file URL there should be no backslashes regardless of platform running on.
 	return "file://" + filepath.ToSlash(isoPath)
 }
@@ -393,6 +398,7 @@ func getDriverOptions(config MachineConfig) (drivers.DriverOptions, error) {
 
 		return createDriverOptions(d, machineConfigOptions)
 	case "vmwarefusion":
+		fmt.Println("VMWare Fusion driver will be deprecated soon. Please consider using other drivers.")
 		if minishiftOs.CurrentOS() != minishiftOs.DARWIN {
 			atexit.ExitWithMessage(1, "vmwarefusion driver is only supported on macOS hosts.")
 		}
