@@ -25,17 +25,19 @@ import (
 )
 
 const (
-	APIServerPort                = 8443             // Port that the API server should listen on
-	MiniShiftEnvPrefix           = "MINISHIFT"      // Prefix for the environmental variables
-	MiniShiftHomeEnv             = "MINISHIFT_HOME" // Environment variable used to change the Minishift home directory
-	VersionPrefix                = "v"
-	MinOpenshiftSupportedVersion = "v3.4.1.12"
-	DefaultMemory                = "2GB"
-	DefaultCPUS                  = 2
-	DefaultDiskSize              = "20GB"
-	UpdateMarkerFileName         = "updated"
-	DefaultMachineName           = "minishift"
-	DefaultProfileName           = "minishift"
+	APIServerPort                    = 8443             // Port that the API server should listen on
+	MiniShiftEnvPrefix               = "MINISHIFT"      // Prefix for the environmental variables
+	MiniShiftHomeEnv                 = "MINISHIFT_HOME" // Environment variable used to change the Minishift home directory
+	VersionPrefix                    = "v"
+	MinimumSupportedOpenShiftVersion = "v3.4.1.12"
+	MinimumOcBinaryVersion           = "v3.6.173.0.63" // For provisioning OpenShift versions < v3.7.0 , we need to use oc v3.6.0. Refer #1417
+	BackwardIncompatibleOcVersion    = "v3.7"          // From v3.7.0 oc binary will not provision older versions of OpenShift instance
+	DefaultMemory                    = "2GB"
+	DefaultCPUS                      = 2
+	DefaultDiskSize                  = "20GB"
+	UpdateMarkerFileName             = "updated"
+	DefaultMachineName               = "minishift"
+	DefaultProfileName               = "minishift"
 )
 
 var (
@@ -60,14 +62,14 @@ func MakeMiniPath(fileName ...string) string {
 	return filepath.Join(args...)
 }
 
-// GetProfileHomeDir determines the Minishift home directory for the profile.
-func GetProfileHomeDir() string {
-	if ProfileName != DefaultProfileName {
+// GetProfileHomeDir determines the base directory for the specified profile name
+func GetProfileHomeDir(profile string) string {
+	if profile != DefaultProfileName {
 		homeEnv, ok := os.LookupEnv(MiniShiftHomeEnv)
 		if ok {
-			return filepath.Join(homeEnv, "profiles", ProfileName)
+			return filepath.Join(homeEnv, "profiles", profile)
 		}
-		return filepath.Join(util.HomeDir(), ".minishift", "profiles", ProfileName)
+		return filepath.Join(util.HomeDir(), ".minishift", "profiles", profile)
 	}
 	return GetMinishiftHomeDir()
 }
