@@ -29,16 +29,18 @@ import (
 	"github.com/golang/glog"
 
 	configCmd "github.com/minishift/minishift/cmd/minishift/cmd/config"
+	"github.com/minishift/minishift/pkg/minikube/constants"
 	"github.com/minishift/minishift/pkg/minikube/kubeconfig"
 	"github.com/minishift/minishift/pkg/minishift/addon/command"
 	"github.com/minishift/minishift/pkg/minishift/addon/manager"
 	minishiftConfig "github.com/minishift/minishift/pkg/minishift/config"
 	"github.com/minishift/minishift/pkg/minishift/oc"
+	openshiftVersion "github.com/minishift/minishift/pkg/minishift/openshift/version"
 
 	"regexp"
 
 	"github.com/minishift/minishift/pkg/util"
-	"github.com/minishift/minishift/pkg/version"
+	minishiftStrings "github.com/minishift/minishift/pkg/util/strings"
 )
 
 const (
@@ -161,12 +163,13 @@ func EnsureHostDirectoriesExist(host *host.Host, dirs []string) error {
 }
 
 // DetermineOcVersion returns the oc version to use.
-// If the requested version is < the base line version we use baseline oc to provision the requested OpenShift version.
-// If the requested OpenShift version is >= the baseline, we align the oc version with the requested OpenShift version.
+// If the requested version is < v3.7.0 we will use oc binary v3.6.0 to provision the requested OpenShift version.
+// If the requested OpenShift version is >= v3.7.0, we align the oc version with the requested OpenShift version.
+// Check Minishift github issue #1417 for details.
 func DetermineOcVersion(requestedVersion string) string {
-	valid, _ := ValidateOpenshiftMinVersion(requestedVersion, version.GetOpenShiftVersion())
+	valid, _ := openshiftVersion.IsGreaterOrEqualToBaseVersion(requestedVersion, constants.BackwardIncompatibleOcVersion)
 	if !valid {
-		requestedVersion = version.GetOpenShiftVersion()
+		requestedVersion = constants.MinimumOcBinaryVersion
 	}
 
 	return requestedVersion
@@ -188,8 +191,13 @@ func GetExecutionContext(ip string, routingSuffix string, addOnEnv []string, ocR
 		if !match {
 			return nil, errors.New(fmt.Sprintf("Add-on interpolation variables need to be specified in the format <key>=<value>.'%s' is not.", env))
 		}
-		key, value := splitKeyValue(env, "=")
 
+		envTokens, err := minishiftStrings.SplitAndTrim(env, "=")
+		if err != nil {
+			return nil, err
+		}
+
+		key, value := envTokens[0], envTokens[1]
 		if strings.HasPrefix(value, envPrefix) {
 			if os.Getenv(strings.TrimPrefix(value, envPrefix)) != "" {
 				value = os.Getenv(strings.TrimPrefix(value, envPrefix))
@@ -204,11 +212,6 @@ func GetExecutionContext(ip string, routingSuffix string, addOnEnv []string, ocR
 	return context, nil
 }
 
-func splitKeyValue(s string, separator string) (string, string) {
-	x := strings.Split(s, separator)
-	return strings.TrimSpace(x[0]), strings.TrimSpace(x[1])
-}
-
 // TODO - persistent volume creation should really be fixed upstream, aka 'cluster up'. See https://github.com/openshift/origin/issues/14076 (HF)
 // configurePersistentVolumes makes sure that the default persistent volumes created by 'cluster up' have the right permissions - see https://github.com/minishift/minishift/issues/856
 func configurePersistentVolumes(hostPvDir string, addOnManager *manager.AddOnManager, sshCommander provision.SSHCommander, ocRunner *oc.OcRunner) error {
@@ -223,29 +226,49 @@ func configurePersistentVolumes(hostPvDir string, addOnManager *manager.AddOnMan
 	var out, err *bytes.Buffer
 
 	// poll the status of the persistent-volume-setup job to determine when the persitent volume creates is completed
+	timeout := time.NewTimer(5 * time.Minute)
+outerPollActive:
 	for {
-		out = new(bytes.Buffer)
-		err = new(bytes.Buffer)
-		exitStatus := ocRunner.Run("get job persistent-volume-setup -n default -o 'jsonpath={ .status.active }'", out, err)
+		select {
+		case <-timeout.C:
+			return errors.New("Timed out to poll active state of persistent-volume-setup job")
+		default:
+			out = new(bytes.Buffer)
+			err = new(bytes.Buffer)
+			exitStatus := ocRunner.Run("get job persistent-volume-setup -n default -o 'jsonpath={ .status.active }'", out, err)
+			if exitStatus != 0 || len(err.String()) > 0 {
+				return errors.New("Unable to monitor persistent volume creation")
+			}
 
-		if exitStatus != 0 || len(err.String()) > 0 {
-			return errors.New("Unable to monitor persistent volume creation")
+			if out.String() != "1" {
+				break outerPollActive
+			}
+
+			time.Sleep(1 * time.Second)
 		}
-
-		if out.String() != "1" {
-			break
-		}
-
-		time.Sleep(1 * time.Second)
 	}
 
-	// verify the job succeeded
-	out = new(bytes.Buffer)
-	err = new(bytes.Buffer)
-	exitStatus := ocRunner.Run("get job persistent-volume-setup -n default -o 'jsonpath={ .status.succeeded }'", out, err)
+	// poll the success status of persistent-volume-setup job.
+outerPollSuccess:
+	for {
+		select {
+		case <-timeout.C:
+			return errors.New("Timed out to poll success state of persistent-volume-setup job")
+		default:
+			out = new(bytes.Buffer)
+			err = new(bytes.Buffer)
+			exitStatus := ocRunner.Run("get job persistent-volume-setup -n default -o 'jsonpath={ .status.succeeded }'", out, err)
 
-	if exitStatus != 0 || len(err.String()) > 0 || out.String() != "1" {
-		return errors.New("Persistent volume creation failed")
+			if exitStatus != 0 || len(err.String()) > 0 {
+				return errors.New("Persistent volume creation failed")
+			}
+
+			if out.String() == "1" {
+				break outerPollSuccess
+			}
+
+			time.Sleep(1 * time.Second)
+		}
 	}
 
 	cmd := fmt.Sprintf("sudo chmod -R 777 %s/pv*", hostPvDir)
@@ -286,10 +309,3 @@ func getConfigClusterName(hostname string, ip string, port int) string {
 	}
 	return fmt.Sprintf("%s:%d", strings.Replace(ip, ".", "-", -1), port)
 }
-
-func ValidateOpenshiftMinVersion(version string, minVersion string) (bool, error) {
-	if util.VersionOrdinal(version) < util.VersionOrdinal(minVersion) {
-		return false, nil
-	}
-	return true, nil
-}
