@@ -28,14 +28,16 @@ import (
 	"github.com/docker/machine/libmachine/state"
 	"github.com/spf13/viper"
 
-	config "github.com/minishift/minishift/pkg/minishift/config"
+	"github.com/minishift/minishift/pkg/minishift/config"
 	minishiftConfig "github.com/minishift/minishift/pkg/minishift/config"
 	miniutil "github.com/minishift/minishift/pkg/minishift/util"
 	"github.com/minishift/minishift/pkg/util"
+	minishiftStrings "github.com/minishift/minishift/pkg/util/strings"
 )
 
 const (
 	HostfoldersAutoMountKey = "hostfolders-automount"
+	NonSupportedTtyError    = "Not a tty supported terminal"
 )
 
 func IsAutoMount() bool {
@@ -62,7 +64,7 @@ func List(driver drivers.Driver, isRunning bool) error {
 
 	procMounts := ""
 	if isRunning {
-		cmd := fmt.Sprintf("cat /proc/mounts")
+		cmd := "cat /proc/mounts"
 		procMounts, _ = drivers.RunSSHCommandFromDriver(driver, cmd)
 	}
 
@@ -111,6 +113,9 @@ func SetupUsers(allInstances bool) error {
 
 	mountpoint := readInputForMountpoint(name)
 	username := util.ReadInputFromStdin("Username")
+	if !util.IsTtySupported() {
+		return fmt.Errorf(NonSupportedTtyError)
+	}
 	password := util.ReadPasswordFromStdin("Password")
 	domain := util.ReadInputFromStdin("Domain")
 	password, err := util.EncryptText(password)
@@ -140,6 +145,9 @@ func Add(name string, allInstances bool) error {
 	}
 	mountpoint := readInputForMountpoint(name)
 	username := util.ReadInputFromStdin("Username")
+	if !util.IsTtySupported() {
+		return fmt.Errorf(NonSupportedTtyError)
+	}
 	password := util.ReadPasswordFromStdin("Password")
 	domain := util.ReadInputFromStdin("Domain")
 	password, err := util.EncryptText(password)
@@ -322,11 +330,11 @@ func mountCifsHostfolder(driver drivers.Driver, hostfolder *config.HostFolder) e
 	}
 
 	cmd := fmt.Sprintf(
-		"sudo mount -t cifs %s %s -o username=%s,password=%s",
+		"sudo mount -t cifs %s %s -o username=%s,password='%s'",
 		hostfolder.Options["uncpath"],
 		hostfolder.Mountpoint(),
 		hostfolder.Options["username"],
-		password)
+		minishiftStrings.EscapeSingleQuote(password))
 
 	if minishiftConfig.InstanceConfig.IsRHELBased {
 		cmd = fmt.Sprintf("%s,context=system_u:object_r:svirt_sandbox_file_t:s0", cmd)
@@ -343,7 +351,7 @@ func mountCifsHostfolder(driver drivers.Driver, hostfolder *config.HostFolder) e
 
 	if _, err := drivers.RunSSHCommandFromDriver(driver, cmd); err != nil {
 		fmt.Println("FAIL")
-		return fmt.Errorf("Error occured while mounting host folder.", err)
+		return fmt.Errorf("Error occured while mounting host folder. %s", err)
 	} else {
 		fmt.Println("OK")
 	}
@@ -353,13 +361,13 @@ func mountCifsHostfolder(driver drivers.Driver, hostfolder *config.HostFolder) e
 
 func umountHostfolder(driver drivers.Driver, hostfolder *config.HostFolder) error {
 	if hostfolder == nil {
-		errors.New("Host folder not defined")
+		return errors.New("Host folder not defined")
 	}
 
 	fmt.Printf("   Unmounting '%s' ... ", hostfolder.Name)
 
 	if isMounted, err := isHostfolderMounted(driver, hostfolder); !isMounted {
-		fmt.Printf("Not mounted\n")
+		fmt.Print("Not mounted\n")
 		return fmt.Errorf("Host folder not mounted. %s", err)
 	}
 
@@ -369,7 +377,7 @@ func umountHostfolder(driver drivers.Driver, hostfolder *config.HostFolder) erro
 
 	if _, err := drivers.RunSSHCommandFromDriver(driver, cmd); err != nil {
 		fmt.Println("FAIL")
-		return fmt.Errorf("Error occured while unmounting host folder.", err)
+		return fmt.Errorf("Error occured while unmounting host folder. %s", err)
 	} else {
 		fmt.Println("OK")
 	}
@@ -415,7 +423,7 @@ func isCifsHostReachable(driver drivers.Driver, uncpath string) bool {
 
 func ensureMountPointExists(driver drivers.Driver, hostfolder *config.HostFolder) error {
 	if hostfolder == nil {
-		errors.New("Host folder is not defined")
+		return errors.New("Host folder is not defined")
 	}
 
 	cmd := fmt.Sprintf(
