@@ -28,8 +28,7 @@ import (
 
 	"github.com/docker/machine/libmachine/host"
 	"github.com/docker/machine/libmachine/provision"
-	"github.com/minishift/minishift/pkg/minishift/clusterup"
-	"github.com/minishift/minishift/pkg/minishift/constants"
+	minishiftConstants "github.com/minishift/minishift/pkg/minishift/constants"
 	"github.com/minishift/minishift/pkg/minishift/docker"
 	"github.com/minishift/minishift/pkg/util"
 )
@@ -51,7 +50,7 @@ type ImageInfo struct {
 func GetOpenshiftVersion(host *host.Host) (string, error) {
 	sshCommander := provision.GenericSSHCommander{Driver: host.Driver}
 	dockerCommander := docker.NewVmDockerCommander(sshCommander)
-	return dockerCommander.Exec(" ", constants.OpenshiftContainerName, "openshift", "version")
+	return dockerCommander.Exec(" ", minishiftConstants.OpenshiftContainerName, "openshift", "version")
 }
 
 func PrintDownStreamVersions(output io.Writer, minSupportedVersion string) error {
@@ -76,6 +75,9 @@ func PrintDownStreamVersions(output io.Writer, minSupportedVersion string) error
 			if strings.Contains(version, "-") {
 				continue
 			}
+			if strings.Count(version, ".") == 1 {
+				continue
+			}
 			tagsList = append(tagsList, version)
 		}
 	}
@@ -105,8 +107,8 @@ func PrintUpStreamVersions(output io.Writer, minSupportedVersion string, default
 		if strings.Contains(imageTag.Name, "latest") {
 			continue
 		}
-		if valid, _ := clusterup.ValidateOpenshiftMinVersion(imageTag.Name, minSupportedVersion); valid {
-			if valid, _ := clusterup.ValidateOpenshiftMinVersion(imageTag.Name, defaultVersion); valid {
+		if valid, _ := IsGreaterOrEqualToBaseVersion(imageTag.Name, minSupportedVersion); valid {
+			if valid, _ := IsGreaterOrEqualToBaseVersion(imageTag.Name, defaultVersion); valid {
 				tagsList = append(tagsList, imageTag.Name)
 			} else {
 				if !isPrerelease(imageTag.Name) {
@@ -136,3 +138,28 @@ func isPrerelease(tag string) bool {
 	}
 	return false
 }
+
+// IsGreaterOrEqualToBaseVersion returns true if the version is greater or equal to the base version
+func IsGreaterOrEqualToBaseVersion(version string, baseVersion string) (bool, error) {
+	if err := validateOcpTag(version); err != nil {
+		return false, err
+	}
+	if util.VersionOrdinal(version) >= util.VersionOrdinal(baseVersion) {
+		return true, nil
+	}
+	return false, nil
+}
+
+// validateOcpTags will return appropriate error message if user has asked for OCP tags like
+// v3.6, 3.7 etc. These tags always point to the latest version in respective branch of OCP
+// release and will not have corresponding oc binary in https://mirror.openshift.com/pub/openshift-v3/clients/
+// In future we need to figureout how to findout the exact OCP version for the tag, so that we can download the
+// correct oc binary.
+func validateOcpTag(version string) error {
+	wrongOcpTagError := "Please see the available versions in the output of 'minishift openshift version list'"
+	matched, _ := regexp.MatchString(`^v(\d+\.)(\d+)$`, version)
+	if matched {
+		return fmt.Errorf("Error: Invalid oc binary version '%s'. %s", version, wrongOcpTagError)
+	}
+	return nil
+}
