@@ -17,7 +17,6 @@ limitations under the License.
 package registration
 
 import (
-	"errors"
 	"fmt"
 	"strings"
 	"time"
@@ -67,6 +66,10 @@ func (registrator *RedHatRegistrator) Register(param *RegistrationParameters) er
 			progressDots := progressdots.New()
 			// request username (disallow empty value)
 			if param.Username == "" {
+				// Check if Terminal tty supported or not
+				if !param.IsTtySupported {
+					return fmt.Errorf(("Not a tty supported terminal, Retries are disabled"))
+				}
 				for param.Username == "" {
 					param.Username = param.GetUsernameInteractive(RHSMName + " username")
 				}
@@ -143,6 +146,4 @@ func (registrator *RedHatRegistrator) isRegistered() (bool, error) {
 		}
 		return false, nil
 	}
-
-	return false, errors.New("Unable to determine registration state")
 }
