@@ -17,6 +17,7 @@ limitations under the License.
 package strings
 
 import (
+	minishiftTesting "github.com/minishift/minishift/pkg/testing"
 	"reflect"
 	"runtime"
 	"testing"
@@ -45,6 +46,24 @@ func TestContains(t *testing.T) {
 	}
 }
 
+func TestRemove(t *testing.T) {
+	var testCases = []struct {
+		slice    []string
+		element  string
+		expected []string
+	}{
+		{[]string{"a", "b", "c"}, "b", []string{"a", "c"}},
+		{[]string{"a", "b", "c"}, "", []string{"a", "b", "c"}},
+		{[]string{"a", "b", "c"}, "d", []string{"a", "b", "c"}},
+		{[]string{}, "a", []string{}},
+	}
+
+	for _, testCase := range testCases {
+		actual := Remove(testCase.slice, testCase.element)
+		minishiftTesting.AssertEqualSlice(testCase.expected, actual, t)
+	}
+}
+
 func TestHasMatcher(t *testing.T) {
 	var testCases = []struct {
 		testString     string
@@ -96,7 +115,7 @@ func TestGetMatcher(t *testing.T) {
 	for _, testCase := range testCases {
 		actualResult := testCase.matcher(testCase.testString)
 		if actualResult != testCase.expectedResult {
-			t.Errorf("Unexpected result for '%s'. Expected '%s' to return '%t', but got '%t'", getFunctionName(testCase.matcher), testCase.testString, testCase.expectedResult, actualResult)
+			t.Errorf("Unexpected result for '%s'. Expected '%s' to return '%s', but got '%s'", getFunctionName(testCase.matcher), testCase.testString, testCase.expectedResult, actualResult)
 		}
 	}
 }
@@ -113,3 +132,22 @@ func TestEscapeSingleQuote(t *testing.T) {
 		}
 	}
 }
+
+func TestSplitAndTrim(t *testing.T) {
+	var testCases = []struct {
+		testString    string
+		separator     string
+		expectedSlice []string
+	}{
+		{"foo bar", " ", []string{"foo", "bar"}},
+		{"foo=bar", "=", []string{"foo", "bar"}},
+		{"foobar", "", []string{"f", "o"}},
+		{"foo:bar-baz", "-", []string{"foo:bar", "baz"}},
+	}
+
+	for _, testCase := range testCases {
+		tokens, _ := SplitAndTrim(testCase.testString, testCase.separator)
+		actualSlice := []string{tokens[0], tokens[1]}
+		minishiftTesting.AssertEqualSlice(actualSlice, testCase.expectedSlice, t)
+	}
+}
