@@ -35,6 +35,7 @@ import (
 	"strconv"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/DATA-DOG/godog"
 	"github.com/DATA-DOG/godog/gherkin"
@@ -55,6 +56,7 @@ var (
 	isoName       string
 
 	runBeforeFeature string
+	testWithShell    string
 
 	// Godog options
 	godogFormat              string
@@ -120,6 +122,7 @@ func parseFlags() {
 	flag.StringVar(&minishiftArgs, "minishift-args", "", "Arguments to pass to minishift")
 	flag.StringVar(&minishiftBinary, "binary", "", "Path to minishift binary")
 	flag.StringVar(&runBeforeFeature, "run-before-feature", "", "Set of minishift commands to be executed before every feature. Individual commands must be delimited by a semicolon.")
+	flag.StringVar(&testWithShell, "test-with-specified-shell", "", "Name of shell to be used for steps which executes commands directly in persistent shell instance.")
 	flag.StringVar(&testDir, "test-dir", "", "Path to the directory in which to execute the tests")
 
 	flag.StringVar(&godogFormat, "format", "pretty", "Sets which format godog will use")
@@ -160,6 +163,10 @@ func FeatureContext(s *godog.Suite) {
 	// steps to execute `minishift` commands
 	s.Step(`^Minishift (?:has|should have) state "(Does Not Exist|Running|Stopped)"$`,
 		minishift.shouldHaveState)
+	s.Step(`^profile (.*) (?:has|should have) state "(Does Not Exist|Running|Stopped)"$`,
+		minishift.profileShouldHaveState)
+	s.Step(`profile (.*) (?:is the|should be the) active profile$`,
+		minishift.isTheActiveProfile)
 	s.Step(`^executing "minishift (.*)"$`,
 		minishift.executingMinishiftCommand)
 	s.Step(`^executing "minishift (.*)" (succeeds|fails)$`,
@@ -180,11 +187,13 @@ func FeatureContext(s *godog.Suite) {
 	// steps for scenario variables
 	s.Step(`^setting scenario variable "(.*)" to the stdout from executing "oc (.*)"$`,
 		minishift.setVariableExecutingOcCommand)
+	s.Step(`^setting scenario variable "(.*)" to the stdout from executing "minishift (.*)"$`,
+		minishift.setVariableExecutingMinishiftCommand)
 	s.Step(`^scenario variable "(.*)" should not be empty$`,
 		variableShouldNotBeEmpty)
 
 	// steps for rollout check
-	s.Step(`^services "([^"]*)" rollout successfully$`,
+	s.Step(`^services? "([^"]*)" rollout successfully$`,
 		minishift.rolloutServicesSuccessfully)
 
 	// steps for proxying
@@ -226,13 +235,19 @@ func FeatureContext(s *godog.Suite) {
 	s.Step(`^(stdout|stderr|exitcode) should not match$`,
 		commandReturnShouldNotMatchRegexContent)
 
-	// step for HTTP requests for minishift web console
-	s.Step(`^(body|status code) of HTTP request to "([^"]*)" (?:|at "([^"]*)" )(contains|is equal to) "(.*)"$`,
-		verifyHTTPResponse)
-
-	// step for HTTP requests for accessing application
-	s.Step(`^(body|status code) of HTTP request to "([^"]*)" of service "([^"]*)" in namespace "([^"]*)" (contains|is equal to) "(.*)"$`,
-		getRoutingUrlAndVerifyHTTPResponse)
+	// step for HTTP requests to OpenShift instance
+	s.Step(`^"(body|status code)" of HTTP request to "([^"]*)" (contains|is equal to) "(.*)"$`,
+		verifyRequestToURL)
+	s.Step(`^with up to "(\d*)" retries with wait period of "(\d*)ms" the "(body|status code)" of HTTP request to "([^"]*)" (contains|is equal to) "(.*)"$`,
+		verifyRequestToURLWithRetry)
+	s.Step(`^"(body|status code)" of HTTP request to "([^"]*)" of OpenShift instance (contains|is equal to) "(.*)"$`,
+		verifyRequestToOpenShift)
+	s.Step(`^with up to "(\d*)" retries with wait period of "(\d*)ms" the "(body|status code)" of HTTP request to "([^"]*)" of OpenShift instance (contains|is equal to) "(.*)"$`,
+		verifyRequestToOpenShiftWithRetry)
+	s.Step(`^"(body|status code)" of HTTP request to "([^"]*)" of service "([^"]*)" in namespace "([^"]*)" (contains|is equal to) "(.*)"$`,
+		verifyRequestToService)
+	s.Step(`^with up to "(\d*)" retries with wait period of "(\d*)ms" the "(body|status code)" of HTTP request to "([^"]*)" of service "([^"]*)" in namespace "([^"]*)" (contains|is equal to) "(.*)"$`,
+		verifyRequestToServiceWithRetry)
 
 	// steps for verifying config file content
 	s.Step(`^(JSON|YAML) config file "(.*)" (contains|does not contain) key "(.*)" with value matching "(.*)"$`,
@@ -253,6 +268,41 @@ func FeatureContext(s *godog.Suite) {
 	s.Step(`^file from "(.*)" is downloaded into location "(.*)"$`,
 		downloadFileIntoLocation)
 
+	// steps for executing commands in shell
+	s.Step(`^user starts shell instance on host machine$`,
+		startHostShellInstance)
+	s.Step(`^user closes shell instance on host machine$`,
+		util.CloseHostShellInstance)
+	s.Step(`^executing "minishift (.*)" in host shell$`,
+		util.ExecuteMinishiftInHostShell)
+	s.Step(`^executing "minishift (.*)" in host shell (succeeds|fails)$`,
+		util.ExecuteMinishiftInHostShellSucceedsOrFails)
+	s.Step(`^executing "(.*)" in host shell$`,
+		util.ExecuteInHostShell)
+	s.Step(`^executing "(.*)" in host shell (succeeds|fails)$`,
+		util.ExecuteInHostShellSucceedsOrFails)
+	s.Step(`^(stdout|stderr) of host shell (?:should contain|contains) "(.*)"$`,
+		util.HostShellCommandReturnShouldContain)
+	s.Step(`^(stdout|stderr) of host shell (?:should not contain|does not contain) "(.*)"$`,
+		util.HostShellCommandReturnShouldNotContain)
+	s.Step(`^(stdout|stderr) of host shell (?:should contain|contains)$`,
+		util.HostShellCommandReturnShouldContainContent)
+	s.Step(`^(stdout|stderr) of host shell (?:should not contain|does not contain)$`,
+		util.HostShellCommandReturnShouldNotContainContent)
+	s.Step(`^(stdout|stderr) of host shell (?:should equal|equals) "(.*)"$`,
+		util.HostShellCommandReturnShouldEqual)
+	s.Step(`^(stdout|stderr) of host shell (?:should equal|equals)$`,
+		util.HostShellCommandReturnShouldEqualContent)
+	s.Step(`^evaluating stdout of the previous command in host shell$`,
+		util.ExecuteInHostShellLineByLine)
+
+	// steps for prototyping or debugging purposes, please do not use in production
+	s.Step(`^user (?:waits|waited) "(\d+)" seconds?$`,
+		func(seconds int) error {
+			time.Sleep(time.Duration(seconds) * time.Second)
+			return nil
+		})
+
 	s.BeforeSuite(func() {
 		testDir = setUp()
 		testResultDir = filepath.Join(testDir, "..", "test-results")
@@ -435,7 +485,7 @@ func configFileContainsKeyMatchingValue(format string, configPath string, condit
 		return err
 	}
 
-	matches, err := performRegexMatch(expectedValue, keyValue)
+	matches, err := util.PerformRegexMatch(expectedValue, keyValue)
 	if err != nil {
 		return err
 	} else if (condition == "contains") && !matches {
@@ -475,7 +525,7 @@ func stdoutContainsKeyMatchingValue(commandField string, format string, conditio
 		return err
 	}
 
-	matches, err := performRegexMatch(expectedValue, keyValue)
+	matches, err := util.PerformRegexMatch(expectedValue, keyValue)
 	if err != nil {
 		return err
 	} else if (condition == "contains") && !matches {
@@ -504,69 +554,6 @@ func stdoutContainsKey(commandField string, format string, condition string, key
 	return nil
 }
 
-func compareExpectedWithActualContains(expected string, actual string) error {
-	if !strings.Contains(actual, expected) {
-		return fmt.Errorf("Output did not match. Expected: '%s', Actual: '%s'", expected, actual)
-	}
-
-	return nil
-}
-
-func compareExpectedWithActualNotContains(notexpected string, actual string) error {
-	if strings.Contains(actual, notexpected) {
-		return fmt.Errorf("Output did match. Not expected: '%s', Actual: '%s'", notexpected, actual)
-	}
-
-	return nil
-}
-
-func compareExpectedWithActualEquals(expected string, actual string) error {
-	if actual != expected {
-		return fmt.Errorf("Output did not match. Expected: '%s', Actual: '%s'", expected, actual)
-	}
-
-	return nil
-}
-
-func compareExpectedWithActualNotEquals(notexpected string, actual string) error {
-	if actual == notexpected {
-		return fmt.Errorf("Output did match. Not expected: '%s', Actual: '%s'", notexpected, actual)
-	}
-
-	return nil
-}
-
-func performRegexMatch(regex string, input string) (bool, error) {
-	compRegex, err := regexp.Compile(regex)
-	if err != nil {
-		return false, fmt.Errorf("Expected value must be a valid regular expression statement: ", err)
-	}
-
-	return compRegex.MatchString(input), nil
-}
-
-func compareExpectedWithActualMatchesRegex(expected string, actual string) error {
-	matches, err := performRegexMatch(expected, actual)
-	if err != nil {
-		return err
-	} else if !matches {
-		return fmt.Errorf("Output did not match. Expected: '%s', Actual: '%s'", expected, actual)
-	}
-
-	return nil
-}
-
-func compareExpectedWithActualNotMatchesRegex(notexpected string, actual string) error {
-	matches, err := performRegexMatch(notexpected, actual)
-	if err != nil {
-		return err
-	} else if matches {
-		return fmt.Errorf("Output did match. Not expected: '%s', Actual: '%s'", notexpected, actual)
-	}
-
-	return nil
-}
-
 func getLastCommandOutput() CommandOutput {
 	return commandOutputs[len(commandOutputs)-1]
 }
@@ -650,71 +637,71 @@ func validateYAML(inputString string) (bool, error) {
 func commandReturnEquals(commandField string, command string, condition string, expected string) error {
 	minishift.executingMinishiftCommand(command)
 	if condition == "is equal" {
-		return compareExpectedWithActualEquals(expected+"\n", selectFieldFromLastOutput(commandField))
+		return util.CompareExpectedWithActualEquals(expected+"\n", selectFieldFromLastOutput(commandField))
 	} else {
-		return compareExpectedWithActualNotEquals(expected+"\n", selectFieldFromLastOutput(commandField))
+		return util.CompareExpectedWithActualNotEquals(expected+"\n", selectFieldFromLastOutput(commandField))
 	}
 }
 
 func commandReturnContains(commandField string, command string, condition string, expected string) error {
 	minishift.executingMinishiftCommand(command)
 	if condition == "contains" {
-		return compareExpectedWithActualContains(expected, selectFieldFromLastOutput(commandField))
+		return util.CompareExpectedWithActualContains(expected, selectFieldFromLastOutput(commandField))
 	} else {
-		return compareExpectedWithActualNotContains(expected, selectFieldFromLastOutput(commandField))
+		return util.CompareExpectedWithActualNotContains(expected, selectFieldFromLastOutput(commandField))
 	}
 }
 
 func commandReturnShouldContain(commandField string, expected string) error {
-	return compareExpectedWithActualContains(expected, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualContains(expected, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldNotContain(commandField string, notexpected string) error {
-	return compareExpectedWithActualNotContains(notexpected, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualNotContains(notexpected, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldContainContent(commandField string, expected *gherkin.DocString) error {
-	return compareExpectedWithActualContains(expected.Content, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualContains(expected.Content, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldNotContainContent(commandField string, notexpected *gherkin.DocString) error {
-	return compareExpectedWithActualNotContains(notexpected.Content, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualNotContains(notexpected.Content, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldEqual(commandField string, expected string) error {
-	return compareExpectedWithActualEquals(expected, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualEquals(expected, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldEqualContent(commandField string, expected *gherkin.DocString) error {
-	return compareExpectedWithActualEquals(expected.Content, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualEquals(expected.Content, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldBeEmpty(commandField string) error {
-	return compareExpectedWithActualEquals("", selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualEquals("", selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldNotBeEmpty(commandField string) error {
-	return compareExpectedWithActualNotEquals("", selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualNotEquals("", selectFieldFromLastOutput(commandField))
 }
 
 func variableShouldNotBeEmpty(variableName string) error {
-	return compareExpectedWithActualNotEquals("", minishift.GetVariableByName(variableName).Value)
+	return util.CompareExpectedWithActualNotEquals("", minishift.GetVariableByName(variableName).Value)
 }
 
 func commandReturnShouldMatchRegex(commandField string, expected string) error {
-	return compareExpectedWithActualMatchesRegex(expected, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualMatchesRegex(expected, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldNotMatchRegex(commandField string, notexpected string) error {
-	return compareExpectedWithActualNotMatchesRegex(notexpected, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualNotMatchesRegex(notexpected, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldMatchRegexContent(commandField string, expected *gherkin.DocString) error {
-	return compareExpectedWithActualMatchesRegex(expected.Content, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualMatchesRegex(expected.Content, selectFieldFromLastOutput(commandField))
 }
 
 func commandReturnShouldNotMatchRegexContent(commandField string, notexpected *gherkin.DocString) error {
-	return compareExpectedWithActualNotMatchesRegex(notexpected.Content, selectFieldFromLastOutput(commandField))
+	return util.CompareExpectedWithActualNotMatchesRegex(notexpected.Content, selectFieldFromLastOutput(commandField))
 }
 
 type commandRunner func(string) error
@@ -752,11 +739,55 @@ func succeedsOrFails(execute commandRunner, command string, expectedResult strin
 	return nil
 }
 
-func verifyHTTPResponse(partOfResponse string, url string, urlSuffix string, assertion string, expected string) error {
-	switch url {
-	case "OpenShift":
-		url = minishift.getOpenShiftUrl() + urlSuffix
+func verifyRequestToURL(partOfResponse string, url string, assertion string, expected string) error {
+	return verifyHTTPResponse(partOfResponse, url, assertion, expected)
+}
+
+func verifyRequestToURLWithRetry(retryCount int, retryWaitPeriod int, partOfResponse string, url string, assertion string, expected string) error {
+	return verifyHTTPResponseWithRetry(partOfResponse, url, assertion, expected, retryCount, retryWaitPeriod)
+}
+
+func verifyRequestToService(partOfResponse string, urlSuffix string, serviceName string, nameSpace string, assertion string, expected string) error {
+	url := minishift.getRoute(serviceName, nameSpace) + urlSuffix
+	return verifyHTTPResponse(partOfResponse, url, assertion, expected)
+}
+
+func verifyRequestToServiceWithRetry(retryCount int, retryWaitPeriod int, partOfResponse string, urlSuffix string, serviceName string, nameSpace string, assertion string, expected string) error {
+	url := minishift.getRoute(serviceName, nameSpace) + urlSuffix
+	return verifyHTTPResponseWithRetry(partOfResponse, url, assertion, expected, retryCount, retryWaitPeriod)
+}
+
+func verifyRequestToOpenShift(partOfResponse string, urlSuffix string, assertion string, expected string) error {
+	url := minishift.getOpenShiftUrl() + urlSuffix
+	return verifyHTTPResponse(partOfResponse, url, assertion, expected)
+}
+
+func verifyRequestToOpenShiftWithRetry(retryCount int, retryWaitPeriod int, partOfResponse string, urlSuffix string, assertion string, expected string) error {
+	url := minishift.getOpenShiftUrl() + urlSuffix
+	return verifyHTTPResponseWithRetry(partOfResponse, url, assertion, expected, retryCount, retryWaitPeriod)
+}
+
+func verifyHTTPResponseWithRetry(partOfResponse string, url string, assertion string, expected string, retryCount int, retryWaitPeriod int) error {
+	var err error
+
+	for i := 0; i <= retryCount; i++ {
+		err = verifyHTTPResponse(partOfResponse, url, assertion, expected)
+		if err == nil {
+			break
+		}
+		if i == retryCount {
+			fmt.Printf("HTTP check (%v) has failed. Error: %v\n", i+1, err)
+			break
+		}
+
+		fmt.Printf("HTTP check (%v) has failed, trying again in %v ms. Error: %v\n", i+1, retryWaitPeriod, err)
+		time.Sleep(time.Millisecond * time.Duration(retryWaitPeriod))
 	}
+
+	return err
+}
+
+func verifyHTTPResponse(partOfResponse string, url string, assertion string, expected string) error {
 	transport := &http.Transport{
 		TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
 	}
@@ -792,25 +823,12 @@ func verifyHTTPResponse(partOfResponse string, url string, urlSuffix string, ass
 	return nil
 }
 
-func getRoutingUrlAndVerifyHTTPResponse(partOfResponse string, urlRoot string, serviceName string, nameSpace string, assertion string, expected string) error {
-	url := minishift.getRoute(serviceName, nameSpace)
-	if urlRoot == "/" {
-		return verifyHTTPResponse(partOfResponse, url, "", assertion, expected)
-	} else if strings.HasPrefix(urlRoot, "/") {
-		url := url + urlRoot
-		return verifyHTTPResponse(partOfResponse, url, "", assertion, expected)
-	} else {
-		return fmt.Errorf("Wrong input format : %s. Input must start with /", urlRoot)
-	}
-	return nil
-}
-
 func proxyLogShouldContain(expected string) error {
-	return compareExpectedWithActualContains(expected, testProxy.GetLog())
+	return util.CompareExpectedWithActualContains(expected, testProxy.GetLog())
 }
 
 func proxyLogShouldContainContent(expected *gherkin.DocString) error {
-	return compareExpectedWithActualContains(expected.Content, testProxy.GetLog())
+	return util.CompareExpectedWithActualContains(expected.Content, testProxy.GetLog())
 }
 
 func catDockerConfigFile() error {
@@ -858,3 +876,7 @@ func downloadFileIntoLocation(downloadURL string, destinationFolder string) erro
 
 	return nil
 }
+
+func startHostShellInstance() error {
+	return util.StartHostShellInstance(testWithShell, minishiftBinary)
+}
